@@ -14,7 +14,7 @@
 #    under the License.
 
 import copy
-from http import client as http
+from http import HTTPStatus
 from unittest import mock
 
 from oslo_serialization import jsonutils
@@ -224,7 +224,7 @@ class VersionsTest(test.NoDBTestCase):
             "version": {
                 "id": "v1.0",
                 "status": "CURRENT",
-                "version": "1.2",
+                "version": "1.3",
                 "min_version": "1.0",
                 "updated": "2016-07-01T11:33:21Z",
                 "links": [
@@ -262,4 +262,4 @@ class VersionsTest(test.NoDBTestCase):
         req = webob.Request.blank('/v1/versions/1234/foo')
         req.accept = "application/json"
         res = req.get_response(self.wsgi_app)
-        self.assertEqual(http.NOT_FOUND, res.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, res.status_int)
